@@ -1,6 +1,4 @@
-/*  $Id$
- *
- *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+/*  Copyright 2006-2011 Enrico Tröger <enrico(at)xfce(dot)org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,7 +38,6 @@
 #include "spell.h"
 #include "dictd.h"
 #include "gui.h"
-#include "searchentry.h"
 
 
 
@@ -245,7 +242,7 @@ void dict_search_word(DictData *dd, const gchar *word)
 	}
 	/* remove leading and trailing spaces */
 	g_strstrip(dd->searched_word);
-	xfd_search_entry_prepend_text(XFD_SEARCH_ENTRY(dd->main_combo), dd->searched_word);
+	gtk_combo_box_prepend_text(GTK_COMBO_BOX(dd->main_combo), dd->searched_word);
 
 	dict_gui_clear_text_buffer(dd);
 
@@ -573,7 +570,7 @@ void dict_drag_data_received(GtkWidget *widget, GdkDragContext *drag_context, gi
 }
 
 
-DictData *dict_create_dictdata()
+DictData *dict_create_dictdata(void)
 {
 	DictData *dd = g_new0(DictData, 1);
 
@@ -626,3 +623,12 @@ void dict_show_msgbox(DictData *dd, gint type, const gchar *text, ...)
 }
 
 
+gchar *dict_get_clipboard_contents(void)
+{
+	gchar *text = gtk_clipboard_wait_for_text(gtk_clipboard_get(GDK_SELECTION_PRIMARY));
+
+	if (! text)
+		text = gtk_clipboard_wait_for_text(gtk_clipboard_get(GDK_SELECTION_PRIMARY));
+
+	return text;
+}
